@@ -113,11 +113,17 @@ def z(col):
 
     """
     desc: |
-        Transforms a column into z scores.
+        Transforms a column into z scores such that the mean of all values is
+        0 and the standard deviation is 1.
         
-        *Version note:* As of 0.13.2, `z()` returns a `FloatColumn`. For
-        non-numeric values, the z score is NAN. If the standard deviation is 0,
-        z scores are also NAN.
+        *Version note:* As of 0.13.2, `z()` returns a `FloatColumn` when a
+        regular column is give. For non-numeric values, the z score is NAN. If
+        the standard deviation is 0, z scores are also NAN.
+        
+        *Version note:* As of 0.15.3, `z()` also accepts series columns, in
+        which case the series is z-transformed such that the grand mean of
+        all samples is 0, and the grand standard deviation of all samples is
+        1.
 
         __Example:__
 
@@ -140,6 +146,12 @@ def z(col):
         type: BaseColumn
     """
 
+    if isinstance(col, _SeriesColumn):
+        import numpy as np
+        from datamatrix import series as srs
+        zcol = col[:]
+        zcol._seq = (zcol._seq - np.nanmean(zcol._seq)) / np.nanstd(zcol._seq)
+        return zcol
     zcol = FloatColumn(col.dm)
     zcol[:] = col
     try:
